"""A CLI + library to spam multiple common anonymous message apps for Snapchat."""
__author__ = "Adam Thompson-Sharpe"
__version__ = "0.2.0"
